CREATE SCHEMA Automatische_Dauerzaehlstelle

-- Historie:
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten)
--
-- 17.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr
-- automat_Dauerzaehlstelle und manuelle_Zaehlstelle
--
-- Verlegung der oertlichen_Zuordnung in das Straennetz
--
-- Verlegung der verwaltungstechn_Zuordnung in die Administration
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE automat_Dauerzaehlstelle (
   automat_Dauerzaehlstelle_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (automat_Dauerzaehlstelle_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (automat_Dauerzaehlstelle_ID) REFERENCES autom_Dauerzaehlst_abstrakt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   TK25_Nummer
      INTEGER NOT NULL, -- TK25_Blattnummer
   CHECK ( ( TK25_Nummer >= 1 ) AND ( TK25_Nummer <= 9999 ) ),
   BASt_Nummer
      INTEGER NOT NULL,
   Name
      VARCHAR(50) NOT NULL,
   hat_Landesnummer
      INTEGER REFERENCES Landesnummer,
   hat_verwaltungstechn_Zuordnung
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordng_AD,
   hat_Moeglichk_z_Einzelfahrzerf
      INTEGER REFERENCES Moegl_Einzelfahrzeugerfassung,
   hat_oertliche_Zuordnung
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_AD
)

CREATE TABLE autom_Dauzaehl__Bezugszaehlst (
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle,
   Bezugszaehlstellen
      INTEGER NOT NULL
)

CREATE TABLE autom_Dauzaehl__hat_Erfasserg (
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle,
   Erfassungsergebnisse
      INTEGER NOT NULL REFERENCES Erfassungsergebnisse
)

CREATE TABLE autom_Dauzaehl__hat_Erfasschar (
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle,
   Erfassungscharakteristik
      INTEGER NOT NULL REFERENCES Erfassungscharakteristik
)

CREATE TABLE autom_Dauzaehl__hat_Detektoren (
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle,
   Detektoren
      INTEGER NOT NULL REFERENCES Detektoren
)

CREATE TABLE autom_Dauzaehl__geh_zu_ZU_VRZ (
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle,
   Unterzentrale_Verkehrsrechnerz
      INTEGER NOT NULL REFERENCES Unterzentrale_Verkehrsrechnerz
)

CREATE TABLE autom_Dauerzaehlst_abstrakt (
   autom_Dauerzaehlst_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_autom_Dauerzaehlst_abstr
      INTEGER NOT NULL REFERENCES Art_autom_Dauerzaehlst_abstr
)

CREATE TABLE Art_autom_Dauerzaehlst_abstr (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(29) NOT NULL
)

INSERT INTO Art_autom_Dauerzaehlst_abstr VALUES (1,'automat_Dauerzaehlstelle')
INSERT INTO Art_autom_Dauerzaehlst_abstr VALUES (2,'autom_Dauerzaehlst_Symbol')

CREATE TABLE autom_Dauerzaehlst_Symbol (
   autom_Dauerzaehlst_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (autom_Dauerzaehlst_Symbol_ID) REFERENCES autom_Dauerzaehlst_abstrakt,
   Kennung
      CHAR(8) NOT NULL
)

CREATE TABLE Erfassungsergebnisse (
   Erfassungsergebnisse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Erfassungsergebnisse_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Ergebnisse
      VARCHAR(99) NOT NULL
)

CREATE TABLE Erfassungserg__von_autom_Dz (
   Erfassungsergebnisse
      INTEGER NOT NULL REFERENCES Erfassungsergebnisse,
   autom_Dauerzaehlst_abstrakt
      INTEGER NOT NULL REFERENCES autom_Dauerzaehlst_abstrakt
)

CREATE TABLE Erfassungscharakteristik (
   Erfassungscharakteristik_ID
      INTEGER NOT NULL PRIMARY KEY,
   Beginn_der_Zaehlung
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Beginn_der_Zaehlung LIKE '__.__.____' ),
   hat_Fahrzeugartenunterscheidg
      INTEGER NOT NULL REFERENCES Fahrzeugartenunterscheidung,
   hat_Differenzierg_d_Erfassung
      INTEGER NOT NULL REFERENCES Differenzierung_der_Erfassung
)

CREATE TABLE Erfcharakt__Zaehlintervlaenge (
   Erfassungscharakteristik
      INTEGER NOT NULL REFERENCES Erfassungscharakteristik,
   Zaehlintervallaenge
      INTEGER NOT NULL REFERENCES Zaehlintervallaenge
)

CREATE TABLE Erfcharakt__hat_Art_d_reg_Dat (
   Erfassungscharakteristik
      INTEGER NOT NULL REFERENCES Erfassungscharakteristik,
   Art_der_registrierten_Daten
      INTEGER NOT NULL REFERENCES Art_der_registrierten_Daten
)

CREATE TABLE Zaehlintervallaenge (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Zaehlintervallaenge VALUES (1,'60 min')
INSERT INTO Zaehlintervallaenge VALUES (2,'30 min')
INSERT INTO Zaehlintervallaenge VALUES (3,'15 min')
INSERT INTO Zaehlintervallaenge VALUES (4,'1 min')
INSERT INTO Zaehlintervallaenge VALUES (5,'5 min')

CREATE TABLE Fahrzeugartenunterscheidung (
   Fahrzeugartenunterscheidung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Unterscheidungsmerkmal
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   Methode_der_Unterscheidung
      INTEGER NOT NULL REFERENCES Methode_der_Unterscheidung
)

CREATE TABLE Fzartuntersch__hat_Kluntersch (
   Fahrzeugartenunterscheidung
      INTEGER NOT NULL REFERENCES Fahrzeugartenunterscheidung,
   Klassenunterscheidung
      INTEGER NOT NULL REFERENCES Klassenunterscheidung
)

CREATE TABLE Klassenunterscheidung (
   Klassenunterscheidung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Klassenunterscheidung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Fahrzeugklasse
      INTEGER NOT NULL REFERENCES Fahrzeugklasse
)

CREATE TABLE Fahrzeugklasse (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Fahrzeugklasse VALUES (0,'keine ' ||
 'Fahrzeugklassenunterscheidung (nur Kfz)')
INSERT INTO Fahrzeugklasse VALUES (1,'Unterscheidung Pkw/Lkw')
INSERT INTO Fahrzeugklasse VALUES (2,'5+1 Fahrzeugklassen')
INSERT INTO Fahrzeugklasse VALUES (3,'8+1 Fahrzeugklassen')
INSERT INTO Fahrzeugklasse VALUES (4,'sonstige')

CREATE TABLE Methode_der_Unterscheidung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Methode_der_Unterscheidung VALUES (0,'Unterscheidung nach ' ||
 'Fahrzeuglngen')
INSERT INTO Methode_der_Unterscheidung VALUES (1,'Unterscheidung nach ' ||
 'Hllkurven')

CREATE TABLE Differenzierung_der_Erfassung (
   Differenzierung_der_Erfassung_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_raeumliche_Differenzierung
      INTEGER NOT NULL REFERENCES raeumliche_Differenzierung
)

CREATE TABLE Diff_d_Erf__hat_Fahrstrzuordn (
   Differenzierung_der_Erfassung
      INTEGER NOT NULL REFERENCES Differenzierung_der_Erfassung,
   Fahrstreifenzuordnung
      INTEGER NOT NULL REFERENCES Fahrstreifenzuordnung
)

CREATE TABLE Fahrstreifenzuordnung (
   Fahrstreifenzuordnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fahrstreifenzuordnung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Fahrstreifen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Fahrstreifen>=0 ),
   Fahrtrichtung
      INTEGER NOT NULL REFERENCES Fahrtrichtung_DE,
   CHECK ( Fahrstreifen<=8 )
)

CREATE TABLE Fahrtrichtung_DE (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Fahrtrichtung_DE VALUES (1,'IN-Richtung')
INSERT INTO Fahrtrichtung_DE VALUES (2,'GEGEN-Richtung')
INSERT INTO Fahrtrichtung_DE VALUES (3,'Gesamtquerschnitt')

CREATE TABLE raeumliche_Differenzierung (
   raeumliche_Differenzierung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Gesamtspuren
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Gesamtspuren>=0 ),
   Spuren_IN_Richtung
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Spuren_IN_Richtung>=0 ),
   Registrierung
      INTEGER NOT NULL REFERENCES Registrierung,
   CHECK ( Spuren_IN_Richtung<=8 ),
   CHECK ( ( Gesamtspuren >= 1 ) AND ( Gesamtspuren <= 8 ) )
)

CREATE TABLE Registrierung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Registrierung VALUES (1,'Gesamtquerschnitt')
INSERT INTO Registrierung VALUES (2,'Trennung nach Fahrtrichtung')
INSERT INTO Registrierung VALUES (3,'Trennung nach Fahrstreifen')

CREATE TABLE Art_der_registrierten_Daten (
   Art_der_registrierten_Daten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Art_der_registrierten_Daten_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Datentyp
      INTEGER NOT NULL REFERENCES Datentyp
)

CREATE TABLE Datentyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Datentyp VALUES (1,'Kfz-Einheiten')
INSERT INTO Datentyp VALUES (2,'Achszahl')
INSERT INTO Datentyp VALUES (3,'Achslasten')
INSERT INTO Datentyp VALUES (4,'Geschwindigkeiten')
INSERT INTO Datentyp VALUES (5,'Sonstiges')

CREATE TABLE Detektoren (
   Detektoren_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Gueltigkeitsbereich
      INTEGER NOT NULL REFERENCES Gueltigkeitsbereich
)

CREATE TABLE Detekt__zugeh_Auswerteschalt (
   Detektoren
      INTEGER NOT NULL REFERENCES Detektoren,
   zugehoerige_Auswerteschaltung
      VARCHAR(20) NOT NULL
)

CREATE TABLE Detektoren__hat_Detektorart (
   Detektoren
      INTEGER NOT NULL REFERENCES Detektoren,
   Detektorart
      INTEGER NOT NULL REFERENCES Detektorart
)

CREATE TABLE Detekt__hat_Art_der_Registrung (
   Detektoren
      INTEGER NOT NULL REFERENCES Detektoren,
   Art_der_Registrierung
      INTEGER NOT NULL REFERENCES Art_der_Registrierung
)

CREATE TABLE Detektorart (
   Detektorart_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Detektorart_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_des_Detektors
      INTEGER NOT NULL REFERENCES Art_des_Detektors
)

CREATE TABLE Art_des_Detektors (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_des_Detektors VALUES (1,'Induktionsschleife')
INSERT INTO Art_des_Detektors VALUES (2,'Schlauch')
INSERT INTO Art_des_Detektors VALUES (3,'Lichtschranke')
INSERT INTO Art_des_Detektors VALUES (4,'Infrarotlicht')
INSERT INTO Art_des_Detektors VALUES (5,'Ultraschall')
INSERT INTO Art_des_Detektors VALUES (6,'Koaxialkabel')
INSERT INTO Art_des_Detektors VALUES (7,'Wiegeplatte')
INSERT INTO Art_des_Detektors VALUES (8,'Wiegeschwelle')
INSERT INTO Art_des_Detektors VALUES (9,'Radar')
INSERT INTO Art_des_Detektors VALUES (10,'Sonstige')
INSERT INTO Art_des_Detektors VALUES (11,'Witterungssensor')
INSERT INTO Art_des_Detektors VALUES (12,'sonstige')

CREATE TABLE Gueltigkeitsbereich (
   Gueltigkeitsbereich_ID
      INTEGER NOT NULL PRIMARY KEY,
   Aufstelldatum
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Aufstelldatum LIKE '__.__.____' ),
   Hersteller
      VARCHAR(50) NOT NULL,
   Abbaudatum
      CHAR(10), -- Datum
   CHECK ( Abbaudatum LIKE '__.__.____' )
)

CREATE TABLE Art_der_Registrierung (
   Art_der_Registrierung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Art_der_Registrierung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Registriermedium
      INTEGER NOT NULL REFERENCES Registriermedium
)

CREATE TABLE Registriermedium (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Registriermedium VALUES (1,'in ablesbaren Zhlwerten')
INSERT INTO Registriermedium VALUES (2,'graphisch')
INSERT INTO Registriermedium VALUES (3,'normale Schriftzeichen')
INSERT INTO Registriermedium VALUES (4,'maschinenlesbare Schriftzeichen')
INSERT INTO Registriermedium VALUES (5,'5-Kanal-CCITT2(Telex)-Code')
INSERT INTO Registriermedium VALUES (6,'8-Kanal-USASCI-Code')
INSERT INTO Registriermedium VALUES (7,'andere')
INSERT INTO Registriermedium VALUES (8,'7-Kanal-Band')
INSERT INTO Registriermedium VALUES (9,'9-Kanal-Band')
INSERT INTO Registriermedium VALUES (10,'Kassettenband')
INSERT INTO Registriermedium VALUES (11,'sonst. Registrierung')

CREATE TABLE Landesnummer (
   Landesnummer_ID
      INTEGER NOT NULL PRIMARY KEY,
   Nummer
      INTEGER NOT NULL,
   Schluessel
      INTEGER NOT NULL,
   CHECK ( (Schluessel=0)OR(Schluessel=1) )
)

CREATE TABLE Moegl_Einzelfahrzeugerfassung (
   Moegl_Einzelfahrzeugerfassung_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Moegl_Einzfzerf__Einzfzdaten (
   Moegl_Einzelfahrzeugerfassung
      INTEGER NOT NULL REFERENCES Moegl_Einzelfahrzeugerfassung,
   Einzelfahrzeugdaten
      VARCHAR(99) NOT NULL
)

CREATE TABLE verwaltungstechn_Zuordng_AD (
   verwaltungstechn_Zuordng_AD_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (verwaltungstechn_Zuordng_AD_ID) REFERENCES Administration.verwaltungstechn_Zuordnung,
   Regionskennziffer
      INTEGER NOT NULL
)

CREATE TABLE verwt_Zuordn_AD__von_autom_Dz (
   verwaltungstechn_Zuordng_AD
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordng_AD,
   autom_Dauerzaehlst_abstrakt
      INTEGER NOT NULL REFERENCES autom_Dauerzaehlst_abstrakt
)

CREATE TABLE oertliche_Zuordnung_AD (
   oertliche_Zuordnung_AD_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_AD_ID) REFERENCES Strassennetz.oertliche_Zuordnung,
   Abschnittslaenge
      REAL -- Kilometer
)

CREATE TABLE oertl_Zuord_AD__hat_Richtungen (
   oertliche_Zuordnung_AD
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_AD,
   Richtungen
      INTEGER NOT NULL REFERENCES Richtungen
)

CREATE TABLE oertl_Zuord_AD__hat_Fahrstrzut (
   oertliche_Zuordnung_AD
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_AD,
   Fahrstreifenzuteilung
      INTEGER NOT NULL REFERENCES Fahrstreifenzuteilung
)

CREATE TABLE oertl_Zuordng_AD__von_autom_DZ (
   oertliche_Zuordnung_AD
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_AD,
   autom_Dauerzaehlst_abstrakt
      INTEGER NOT NULL REFERENCES autom_Dauerzaehlst_abstrakt
)

CREATE TABLE Richtungen (
   Richtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Nahziel_IN_Richtung
      VARCHAR(50) NOT NULL,
   Nahziel_GEGEN_Richtung
      VARCHAR(50) NOT NULL,
   Fernziel_IN_Richtung
      VARCHAR(50) NOT NULL,
   Fernziel_GEGEN_Richtung
      VARCHAR(50) NOT NULL,
   Richtung_IN
      INTEGER NOT NULL REFERENCES Himmelsrichtung,
   Richtung_GEGEN
      INTEGER NOT NULL REFERENCES Himmelsrichtung
)

CREATE TABLE Himmelsrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Himmelsrichtung VALUES (1,'Norden')
INSERT INTO Himmelsrichtung VALUES (2,'Osten')
INSERT INTO Himmelsrichtung VALUES (3,'Sden')
INSERT INTO Himmelsrichtung VALUES (4,'Westen')

CREATE TABLE Fahrstreifenzuteilung (
   Fahrstreifenzuteilung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fahrstreifenzuteilung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Zahl_der_Fahrstreifen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Zahl_der_Fahrstreifen>=0 ),
   Zahl_der_Fahrstr_IN_Richtung
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Zahl_der_Fahrstr_IN_Richtung>=0 )
)

CREATE TABLE Unterzentrale_Verkehrsrechnerz (
   Unterzentrale_Verkehrsrechnerz_ID
      INTEGER NOT NULL PRIMARY KEY,
   Zuordnung
      INTEGER REFERENCES Zuordnung
)

CREATE TABLE Unterzentr_Verkrechnzent__Name (
   Unterzentrale_Verkehrsrechnerz
      INTEGER NOT NULL REFERENCES Unterzentrale_Verkehrsrechnerz,
   Name
      VARCHAR(99) NOT NULL
)

CREATE TABLE Uz_Vrz__von_autom_Dauerzaehlst (
   Unterzentrale_Verkehrsrechnerz
      INTEGER NOT NULL REFERENCES Unterzentrale_Verkehrsrechnerz,
   autom_Dauerzaehlst_abstrakt
      INTEGER NOT NULL REFERENCES autom_Dauerzaehlst_abstrakt
)

CREATE TABLE Zuordnung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Zuordnung VALUES (0,'keine Zuordnung')
INSERT INTO Zuordnung VALUES (1,'Zuordnung zu einer oder mehreren ' ||
 'Unterzentralen')
INSERT INTO Zuordnung VALUES (2,'Zuordnung zu einer oder mehreren ' ||
 'Verkehrsrechnerzentralen')



CREATE SCHEMA Verkehrsstaerke

-- Historie:
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten)
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Verkehrsstaerkekennwerte (
   Verkehrsstaerkekennwerte_ID
      INTEGER NOT NULL PRIMARY KEY,
   werden_addiert_zu_Tageswert_q
      INTEGER REFERENCES Tageswert_q,
   abbildbar_als_Wtganglinien
      INTEGER REFERENCES Wochentagsganglinien_q,
   abbildbar_als_Tganglinien
      INTEGER REFERENCES Tagesganglinien_q
)

CREATE TABLE Verkstaerkekw__sind_Verkstaerk (
   Verkehrsstaerkekennwerte
      INTEGER NOT NULL REFERENCES Verkehrsstaerkekennwerte,
   Verkehrsstaerken
      INTEGER NOT NULL REFERENCES Verkehrsstaerken
)

CREATE TABLE Verkstaerkekw__hat_zeitl_Zuord (
   Verkehrsstaerkekennwerte
      INTEGER NOT NULL REFERENCES Verkehrsstaerkekennwerte,
   zeitliches_Zuordnungskriterium
      INTEGER NOT NULL REFERENCES zeitliches_Zuordnungskriterium
)

CREATE TABLE Verkehrsstaerken (
   Verkehrsstaerken_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Verkstaerk__hat_Verkstarkevert (
   Verkehrsstaerken
      INTEGER NOT NULL REFERENCES Verkehrsstaerken,
   Verkehrsstaerkeverteilung
      INTEGER NOT NULL REFERENCES Verkehrsstaerkeverteilung
)

CREATE TABLE Verkehrsstaerkeverteilung (
   Verkehrsstaerkeverteilung_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Verkstaerkevert__zug_Fz_Kl_VS (
   Verkehrsstaerkeverteilung
      INTEGER NOT NULL REFERENCES Verkehrsstaerkeverteilung,
   zugehoerige_FZ_Klasse_VS
      INTEGER NOT NULL
)

CREATE TABLE Verkstaerkevert__Verkstaerkew (
   Verkehrsstaerkeverteilung
      INTEGER NOT NULL REFERENCES Verkehrsstaerkeverteilung,
   Verkehrsstaerkewert
      INTEGER NOT NULL
)

CREATE TABLE Tageswert_q (
   Tageswert_q_ID
      INTEGER NOT NULL PRIMARY KEY,
   Wert
      INTEGER NOT NULL, -- Kfz_pro_Stunde
   CHECK ( Wert>=0 ),
   Datum
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Datum LIKE '__.__.____' ),
   werden_aufbereitet_zu_Wgangl
      INTEGER REFERENCES Wochenganglinie_q,
   werden_aufbereitet_zu_Jgangl
      INTEGER REFERENCES Jahresganglinie_q
)

CREATE TABLE Wochenganglinie_q (
   Wochenganglinie_q_ID
      INTEGER NOT NULL PRIMARY KEY,
   Woche
      INTEGER NOT NULL, -- Woche
   CHECK ( ( Woche >= 1 ) AND ( Woche <= 53 ) ),
   Jahr
      INTEGER NOT NULL, -- Jahr
   Ganglinientyp
      CHAR(1), -- Ganglinientyp
   CHECK ( ( Ganglinientyp >= 'A' ) AND ( Ganglinientyp <= 'F' ) )
)

CREATE TABLE Jahresganglinie_q (
   Jahresganglinie_q_ID
      INTEGER NOT NULL PRIMARY KEY,
   Jahr
      INTEGER NOT NULL, -- Jahr
   Ganglinientyp
      CHAR(1), -- Ganglinientyp
   CHECK ( ( Ganglinientyp >= 'A' ) AND ( Ganglinientyp <= 'F' ) )
)

CREATE TABLE Tagesganglinien_q (
   Tagesganglinien_q_ID
      INTEGER NOT NULL PRIMARY KEY,
   Datum
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Datum LIKE '__.__.____' )
)

CREATE TABLE Wochentagskennung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(28) NOT NULL
)

INSERT INTO Wochentagskennung VALUES (1,'montags')
INSERT INTO Wochentagskennung VALUES (2,'dienstags bis donnerstags')
INSERT INTO Wochentagskennung VALUES (3,'feiertags')
INSERT INTO Wochentagskennung VALUES (4,'samstags und sonntags')

CREATE TABLE Wochentagsganglinien_q (
   Wochentagsganglinien_q_ID
      INTEGER NOT NULL PRIMARY KEY,
   Wochentag
      INTEGER NOT NULL REFERENCES Allgemeine_Objekte.Wochentag,
   Jahr
      INTEGER NOT NULL, -- Jahr
   Wochentagskennung
      INTEGER REFERENCES Wochentagskennung,
   Ganglinientyp
      CHAR(1), -- Ganglinientyp
   CHECK ( ( Ganglinientyp >= 'A' ) AND ( Ganglinientyp <= 'F' ) )
)

CREATE TABLE zeitliches_Zuordnungskriterium (
   zeitliches_Zuordnungskriterium_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_zeitl_Zuordnungskriterium
      INTEGER NOT NULL REFERENCES Art_zeitl_Zuordnungskriterium
)

CREATE TABLE Art_zeitl_Zuordnungskriterium (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(18) NOT NULL
)

INSERT INTO Art_zeitl_Zuordnungskriterium VALUES (1,'Tageszeitwert')
INSERT INTO Art_zeitl_Zuordnungskriterium VALUES (2,'Nachtzeitwert')
INSERT INTO Art_zeitl_Zuordnungskriterium VALUES (3,'alle_Tage')
INSERT INTO Art_zeitl_Zuordnungskriterium VALUES (4,'werktags')
INSERT INTO Art_zeitl_Zuordnungskriterium VALUES (5,'sonn_und_feiertags')
INSERT INTO Art_zeitl_Zuordnungskriterium VALUES (6,'ferienwerktags')
INSERT INTO Art_zeitl_Zuordnungskriterium VALUES (7,'Di_bis_Do')

CREATE TABLE Tageszeitwert (
   Tageszeitwert_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tageszeitwert_ID) REFERENCES zeitliches_Zuordnungskriterium,
   Zeitbereich
      INTEGER NOT NULL,
   massgebender_Wert_M_T
      INTEGER, -- Kfz_pro_Tag
   CHECK ( massgebender_Wert_M_T>=0 )
)

CREATE TABLE Nachtzeitwert (
   Nachtzeitwert_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nachtzeitwert_ID) REFERENCES zeitliches_Zuordnungskriterium,
   Zeitbereich
      INTEGER NOT NULL,
   massgebender_Wert_M_N
      INTEGER, -- Kfz_pro_Tag
   CHECK ( massgebender_Wert_M_N>=0 )
)

CREATE TABLE alle_Tage (
   alle_Tage_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (alle_Tage_ID) REFERENCES zeitliches_Zuordnungskriterium,
   Zeitbereich
      VARCHAR(30) NOT NULL,
   DTV
      INTEGER NOT NULL, -- Kfz_pro_Tag
   CHECK ( DTV>=0 ),
   DTV_Lkw
      INTEGER, -- Lkw_pro_Tag
   CHECK ( DTV_Lkw>=0 ),
   Lkw_Anteil
      REAL, -- Prozent
   MSV
      INTEGER NOT NULL, -- Kfz_pro_Stunde
   CHECK ( MSV>=0 ),
   MSV_Lkw
      INTEGER, -- Lkw_pro_Stunde
   CHECK ( MSV_Lkw>=0 )
)

CREATE TABLE werktags (
   werktags_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (werktags_ID) REFERENCES zeitliches_Zuordnungskriterium,
   DTV_W
      INTEGER NOT NULL, -- Kfz_pro_Tag
   CHECK ( DTV_W>=0 ),
   DTV_W_Lkw
      INTEGER, -- Lkw_pro_Tag
   CHECK ( DTV_W_Lkw>=0 ),
   MSV_W
      INTEGER NOT NULL, -- Kfz_pro_Stunde
   CHECK ( MSV_W>=0 ),
   MSV_W_Lkw
      INTEGER, -- Lkw_pro_Stunde
   CHECK ( MSV_W_Lkw>=0 )
)

CREATE TABLE werktags__Zeitbereich (
   werktags
      INTEGER NOT NULL REFERENCES werktags,
   Zeitbereich
      VARCHAR(28) NOT NULL
)

CREATE TABLE sonn_und_feiertags (
   sonn_und_feiertags_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (sonn_und_feiertags_ID) REFERENCES zeitliches_Zuordnungskriterium,
   Anzahl
      INTEGER NOT NULL,
   Jahr
      INTEGER NOT NULL, -- Jahr
   DTV_S
      INTEGER NOT NULL, -- Kfz_pro_Tag
   CHECK ( DTV_S>=0 ),
   MSV_S
      INTEGER NOT NULL, -- Kfz_pro_Stunde
   CHECK ( MSV_S>=0 )
)

CREATE TABLE ferienwerktags (
   ferienwerktags_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (ferienwerktags_ID) REFERENCES zeitliches_Zuordnungskriterium,
   DTV_F
      INTEGER NOT NULL, -- Kfz_pro_Tag
   CHECK ( DTV_F>=0 ),
   DTV_F_Lkw
      INTEGER, -- Lkw_pro_Tag
   CHECK ( DTV_F_Lkw>=0 ),
   MSV_F
      INTEGER NOT NULL, -- Kfz_pro_Stunde
   CHECK ( MSV_F>=0 ),
   MSV_F_Lkw
      INTEGER, -- Lkw_pro_Stunde
   CHECK ( MSV_F_Lkw>=0 )
)

CREATE TABLE ferienwerktags__Zeitbereich (
   ferienwerktags
      INTEGER NOT NULL REFERENCES ferienwerktags,
   Zeitbereich
      VARCHAR(30) NOT NULL
)

CREATE TABLE Di_bis_Do (
   Di_bis_Do_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Di_bis_Do_ID) REFERENCES zeitliches_Zuordnungskriterium,
   Zeitbereich
      VARCHAR(30) NOT NULL,
   DTV_Di_bis_Do
      INTEGER NOT NULL, -- Kfz_pro_Tag
   CHECK ( DTV_Di_bis_Do>=0 )
)



CREATE SCHEMA Erfassung_Geschwindigkeiten

-- Historie:
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten)
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Erfassung_Geschwindigkeiten (
   Erfassung_Geschwindigkeiten_ID
      INTEGER NOT NULL PRIMARY KEY,
   zugehoerige_Fahrzeugklasse
      INTEGER NOT NULL
)

CREATE TABLE Erf_Geschw__hat_V_Verteilungen (
   Erfassung_Geschwindigkeiten
      INTEGER NOT NULL REFERENCES Erfassung_Geschwindigkeiten,
   V_Verteilungen
      INTEGER NOT NULL REFERENCES V_Verteilungen
)

CREATE TABLE Erf_Geschw__hat_aggreg_Werte (
   Erfassung_Geschwindigkeiten
      INTEGER NOT NULL REFERENCES Erfassung_Geschwindigkeiten,
   aggregierte_Werte
      INTEGER NOT NULL REFERENCES aggregierte_Werte
)

CREATE TABLE V_Verteilungen (
   V_Verteilungen_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE V_Verteilung__hat_Anzahl_V_Kl (
   V_Verteilungen
      INTEGER NOT NULL REFERENCES V_Verteilungen,
   Anzahl_V_Klassen
      INTEGER NOT NULL REFERENCES Anzahl_V_Klassen
)

CREATE TABLE V_Verteilungen__hat_V_Klassen (
   V_Verteilungen
      INTEGER NOT NULL REFERENCES V_Verteilungen,
   V_Klassen
      INTEGER NOT NULL REFERENCES V_Klassen
)

CREATE TABLE Anzahl_V_Klassen (
   Anzahl_V_Klassen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Fahrzeugklasse
      INTEGER NOT NULL,
   Anzahl_V_Klassen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_V_Klassen>=0 ),
   CHECK ( Anzahl_V_Klassen<=16 ),
   CHECK ( Fahrzeugklasse>=1 )
)

CREATE TABLE V_Klassen (
   V_Klassen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klassennummer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Klassennummer >= 0 ) AND ( Klassennummer <= 99 ) ),
   Klassengrenze
      INTEGER NOT NULL,
   Klassenwert
      INTEGER NOT NULL
)

CREATE TABLE V_Kl__hat_abgel_Wert_u_Verteil (
   V_Klassen
      INTEGER NOT NULL REFERENCES V_Klassen,
   abgel_Werte_u_Verteilgen_VK
      INTEGER NOT NULL REFERENCES abgel_Werte_u_Verteilgen_VK
)

CREATE TABLE abgel_Werte_u_Verteilgen_VK (
   abgel_Werte_u_Verteilgen_VK_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE aggregierte_Werte (
   aggregierte_Werte_ID
      INTEGER NOT NULL PRIMARY KEY,
   Standardabweichung
      INTEGER, -- Stundenkilometer
   CHECK ( Standardabweichung>=0 ),
   v85
      INTEGER, -- Stundenkilometer
   CHECK ( v85>=0 ),
   hat_mittlere_Geschwindigkeit
      INTEGER NOT NULL REFERENCES mittlere_Geschwindigkeit,
   CHECK ( v85<=254 ),
   CHECK ( Standardabweichung<=255 )
)

CREATE TABLE mittlere_Geschwindigkeit (
   mittlere_Geschwindigkeit_ID
      INTEGER NOT NULL PRIMARY KEY,
   Geschwindigkeit
      INTEGER NOT NULL, -- Stundenkilometer
   CHECK ( Geschwindigkeit>=0 ),
   CHECK ( Geschwindigkeit<=255 )
)

CREATE TABLE mittl_Geschw__hat_abgel_Werte (
   mittlere_Geschwindigkeit
      INTEGER NOT NULL REFERENCES mittlere_Geschwindigkeit,
   abgeleitete_Werte_VM
      INTEGER NOT NULL REFERENCES abgeleitete_Werte_VM
)

CREATE TABLE abgeleitete_Werte_VM (
   abgeleitete_Werte_VM_ID
      INTEGER NOT NULL PRIMARY KEY
)



CREATE SCHEMA Achslastdaten

-- Historie:
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten)
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Achslastdatenerfassung (
   Achslastdatenerfassung_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Achsldaterf__hat_GG_Vert_Fz_Kl (
   Achslastdatenerfassung
      INTEGER NOT NULL REFERENCES Achslastdatenerfassung,
   GG_Verteilung_einer_FZ_Klasse
      INTEGER NOT NULL REFERENCES GG_Verteilung_einer_FZ_Klasse
)

CREATE TABLE Achsldaterf__hat_Achslvrt_Atyp (
   Achslastdatenerfassung
      INTEGER NOT NULL REFERENCES Achslastdatenerfassung,
   Achslastverteilung_e_Achstyps
      INTEGER NOT NULL REFERENCES Achslastverteilung_e_Achstyps
)

CREATE TABLE Achsldaterf__hat_abgel_W_u_V (
   Achslastdatenerfassung
      INTEGER NOT NULL REFERENCES Achslastdatenerfassung,
   abgel_Werte_und_Verteilungen
      INTEGER NOT NULL REFERENCES abgel_Werte_und_Verteilungen
)

CREATE TABLE abgel_Werte_und_Verteilungen (
   abgel_Werte_und_Verteilungen_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE GG_Verteilung_einer_FZ_Klasse (
   GG_Verteilung_einer_FZ_Klasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Fahrzeugklasse
      INTEGER NOT NULL,
   Anzahl_der_GG_Klassen_FZ_Kl_3
      INTEGER NOT NULL,
   Anzahl_der_GG_Klassen_FZ_Kl_4
      INTEGER NOT NULL,
   Anzahl_der_GG_Klassen_FZ_Kl_5
      INTEGER NOT NULL,
   Anzahl_Ueberladungen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_Ueberladungen>=0 ),
   CHECK ( Anzahl_Ueberladungen<=255 ),
   CHECK ( ( Fahrzeugklasse >= 3 ) AND ( Fahrzeugklasse <= 5 ) )
)

CREATE TABLE GG_Vert_Fz_Kl__hat_GG_Klasse (
   GG_Verteilung_einer_FZ_Klasse
      INTEGER NOT NULL REFERENCES GG_Verteilung_einer_FZ_Klasse,
   GG_Klasse
      INTEGER NOT NULL REFERENCES GG_Klasse
)

CREATE TABLE GG_Klasse (
   GG_Klasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klassennummer
      INTEGER NOT NULL,
   Klassengrenze
      REAL NOT NULL, -- Groesse
   CHECK ( Klassengrenze>=0 ),
   Klassenwert
      INTEGER NOT NULL, -- Klassenwert
   CHECK ( Klassenwert<=65535 ),
   CHECK ( Klassenwert>=0 ),
   CHECK ( ( Klassennummer >= 1 ) AND ( Klassennummer <= 8 ) )
)

CREATE TABLE Achstyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Achstyp VALUES (1,'Einfachachse')
INSERT INTO Achstyp VALUES (2,'Doppelachse')
INSERT INTO Achstyp VALUES (3,'Dreifachachse')

CREATE TABLE Achslastverteilung_e_Achstyps (
   Achslastverteilung_e_Achstyps_ID
      INTEGER NOT NULL PRIMARY KEY,
   Achstyp
      INTEGER NOT NULL REFERENCES Achstyp,
   Anz_d_Klassen_f_Einzelachsen
      INTEGER NOT NULL, -- Anzahl_Klassen
   CHECK ( ( Anz_d_Klassen_f_Einzelachsen >= 1 ) AND ( Anz_d_Klassen_f_Einzelachsen <= 99 ) ),
   Anz_d_Klassen_f_Doppelachsen
      INTEGER NOT NULL, -- Anzahl_Klassen
   CHECK ( ( Anz_d_Klassen_f_Doppelachsen >= 1 ) AND ( Anz_d_Klassen_f_Doppelachsen <= 99 ) ),
   Anz_d_Klassen_f_Dreifachachsen
      INTEGER NOT NULL, -- Anzahl_Klassen
   CHECK ( ( Anz_d_Klassen_f_Dreifachachsen >= 1 ) AND ( Anz_d_Klassen_f_Dreifachachsen <= 99 ) ),
   hat_Klasse_AL
      INTEGER NOT NULL REFERENCES Klasse_AL
)

CREATE TABLE Klasse_AL (
   Klasse_AL_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klassennummer
      INTEGER NOT NULL,
   Klassengrenze
      REAL NOT NULL, -- Groesse
   CHECK ( Klassengrenze>=0 ),
   Klassenwert
      INTEGER NOT NULL, -- Klassenwert
   CHECK ( Klassenwert<=65535 ),
   CHECK ( Klassenwert>=0 ),
   CHECK ( ( Klassennummer >= 0 ) AND ( Klassennummer <= 99 ) )
)



CREATE SCHEMA Einzelfahrzeugdaten

-- Historie:
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten)
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Einzelfahrzeugdatenerfassung (
   Einzelfahrzeugdatenerfassung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Nettozeitluecke_z_vorherig_FZ
      INTEGER, -- Millisekunden
   CHECK ( Nettozeitluecke_z_vorherig_FZ>=0 ),
   Geschwindigkeit
      INTEGER NOT NULL, -- Stundenkilometer
   CHECK ( Geschwindigkeit>=0 ),
   Fahrzeuglaenge
      REAL, -- Zentimeter
   CHECK ( Fahrzeuglaenge>=0 ),
   Abstand_zum_vorausfahrenden_FZ
      REAL, -- Zentimeter
   CHECK ( Abstand_zum_vorausfahrenden_FZ>=0 ),
   hat_zugehoerige_Fahrzeugklasse
      INTEGER NOT NULL REFERENCES zugehoerige_Fahrzeugklasse,
   hat_zugehoerigen_Zeitpunkt
      INTEGER NOT NULL REFERENCES zugehoeriger_Zeitpunkt,
   hat_fahrzeugbez_Achslastdaten
      INTEGER REFERENCES fahrzeugbezogene_Achslastdaten,
   CHECK ( Geschwindigkeit<=255 )
)

CREATE TABLE Einzfzdaterf__hat_achsbez_Dat (
   Einzelfahrzeugdatenerfassung
      INTEGER NOT NULL REFERENCES Einzelfahrzeugdatenerfassung,
   achsbezogene_Daten
      INTEGER NOT NULL REFERENCES achsbezogene_Daten
)

CREATE TABLE zugehoerige_Fahrzeugklasse (
   zugehoerige_Fahrzeugklasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klasse
      VARCHAR(20) NOT NULL,
   Typ
      VARCHAR(20) NOT NULL
)

CREATE TABLE zugehoeriger_Zeitpunkt (
   zugehoeriger_Zeitpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Datum
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Datum LIKE '__.__.____' ),
   Uhrzeit
      VARCHAR(12) NOT NULL, -- Uhrzeit
   CHECK ( ( Uhrzeit LIKE '__:__' ) OR ( Uhrzeit LIKE '__:__:__' ) OR ( Uhrzeit LIKE '__:__:__:___' ) )
)

CREATE TABLE fahrzeugbezogene_Achslastdaten (
   fahrzeugbezogene_Achslastdaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Anzahl_der_Achsen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_der_Achsen>=0 ),
   Gesamtgewicht
      REAL NOT NULL, -- Kilogramm
   CHECK ( Gesamtgewicht>=0 ),
   hat_Ueberladung
      INTEGER NOT NULL REFERENCES Ueberladung
)

CREATE TABLE Ueberladung (
   Ueberladung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Ueberladung_vorhanden
      INTEGER REFERENCES Logical_Types.Boolean,
   Ueberladung
      REAL, -- Kilogramm
   CHECK ( Ueberladung>=0 )
)

CREATE TABLE achsbezogene_Daten (
   achsbezogene_Daten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Achsabstand_zur_Vorderachse
      REAL NOT NULL, -- Zentimeter
   CHECK ( Achsabstand_zur_Vorderachse>=0 ),
   Achslast
      REAL NOT NULL, -- Kilogramm
   CHECK ( Achslast>=0 ),
   Achstyp
      INTEGER NOT NULL REFERENCES Achslastdaten.Achstyp,
   hat_Ueberladung
      INTEGER NOT NULL REFERENCES Ueberladung
)



CREATE SCHEMA Manuelle_Zaehlstelle

-- Historie:
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten)
--
-- 17.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr
-- automat_Dauerzaehlstelle und manuelle_Zaehlstelle
--
-- Verlegung der oertlichen_Zuordnung in das Straennetz
-- Verlegung der verwaltungstechn_Zuordnung in die Administration
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE manuelle_Zaehlstelle (
   manuelle_Zaehlstelle_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (manuelle_Zaehlstelle_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (manuelle_Zaehlstelle_ID) REFERENCES manuelle_Zaehlst_abstrakt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   TK25_Blattnummer
      INTEGER NOT NULL, -- TK25_Blattnummer
   CHECK ( ( TK25_Blattnummer >= 1 ) AND ( TK25_Blattnummer <= 9999 ) ),
   Zaehlstellennummer
      INTEGER NOT NULL,
   hat_Erfassung_Auslaenderverk
      INTEGER REFERENCES Erfassung_Auslaenderverkehr,
   hat_keine_Erfassung_AV
      INTEGER REFERENCES keine_Erfassung_AV,
   hat_verwaltungstechn_Zuordnung
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordng_MZ,
   hat_Charakteristik
      INTEGER NOT NULL REFERENCES Charakteristik,
   hat_oertliche_Zuordnung
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_MZ,
   hat_Angaben_zur_letzten_Zaehlg
      INTEGER NOT NULL REFERENCES Angaben_zur_letzten_Zaehlung,
   CHECK ( ( hat_Erfassung_Auslaenderverk IS NULL ) OR ( hat_keine_Erfassung_AV IS NULL ) )
)

CREATE TABLE manu_Zaehlst__hat_Erf_Gesverk (
   manuelle_Zaehlstelle
      INTEGER NOT NULL REFERENCES manuelle_Zaehlstelle,
   Erfassung_Gesamtverkehr
      INTEGER NOT NULL REFERENCES Erfassung_Gesamtverkehr
)

CREATE TABLE manu_Zaehlst__hat_Hochrechnerg (
   manuelle_Zaehlstelle
      INTEGER NOT NULL REFERENCES manuelle_Zaehlstelle,
   Hochrechnungsergebnisse
      INTEGER NOT NULL REFERENCES Hochrechnungsergebnisse
)

CREATE TABLE manu_Zaehlst__hat_Bezzst_Auslv (
   manuelle_Zaehlstelle
      INTEGER NOT NULL REFERENCES manuelle_Zaehlstelle,
   Bezugszaehlstelle_Auslverkehr
      INTEGER NOT NULL REFERENCES Bezugszaehlstelle_Auslverkehr
)

CREATE TABLE manu_Zaehlst__hat_Bezzst_Gesvk (
   manuelle_Zaehlstelle
      INTEGER NOT NULL REFERENCES manuelle_Zaehlstelle,
   Bezugszaehlstelle_Gesamtverk
      INTEGER NOT NULL REFERENCES Bezugszaehlstelle_Gesamtverk
)

CREATE TABLE manuelle_Zaehlst_abstrakt (
   manuelle_Zaehlst_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_manuelle_Zaehlstelle_abstr
      INTEGER NOT NULL REFERENCES Art_manuelle_Zaehlstelle_abstr
)

CREATE TABLE Art_manuelle_Zaehlstelle_abstr (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(27) NOT NULL
)

INSERT INTO Art_manuelle_Zaehlstelle_abstr VALUES (1,'manuelle_Zaehlstelle')
INSERT INTO Art_manuelle_Zaehlstelle_abstr VALUES (2,'manuelle_Zaehlst_Symbol')

CREATE TABLE manuelle_Zaehlst_Symbol (
   manuelle_Zaehlst_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (manuelle_Zaehlst_Symbol_ID) REFERENCES manuelle_Zaehlst_abstrakt,
   Kennung
      CHAR(8) NOT NULL
)

CREATE TABLE Erfassung_Gesamtverkehr (
   Erfassung_Gesamtverkehr_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Erfassung_Gesamtverkehr_ID) REFERENCES Strassennetz.Streckenobjekt_stat,
   Abschnittslaenge
      REAL NOT NULL -- Kilometer
)

CREATE TABLE Erfassung_Auslaenderverkehr (
   Erfassung_Auslaenderverkehr_ID
      INTEGER NOT NULL PRIMARY KEY,
   Abschnittslaenge
      REAL NOT NULL -- Kilometer
)

CREATE TABLE Erfass_Auslverk__hat_Gueltber (
   Erfassung_Auslaenderverkehr
      INTEGER NOT NULL REFERENCES Erfassung_Auslaenderverkehr,
   Gueltigkeitsbereich_AV
      INTEGER NOT NULL REFERENCES Gueltigkeitsbereich_AV
)

CREATE TABLE Gueltigkeitsbereich_AV (
   Gueltigkeitsbereich_AV_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Gueltigkeitsbereich_AV_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Beginn
      INTEGER NOT NULL,
   Ende
      INTEGER NOT NULL
)

CREATE TABLE keine_Erfassung_AV (
   keine_Erfassung_AV_ID
      INTEGER NOT NULL PRIMARY KEY,
   Erfassungsart
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean
)

CREATE TABLE verwaltungstechn_Zuordng_MZ (
   verwaltungstechn_Zuordng_MZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (verwaltungstechn_Zuordng_MZ_ID) REFERENCES Administration.verwaltungstechn_Zuordnung
)

CREATE TABLE verwtechn_Zuord_MZ__hat_Verwkz (
   verwaltungstechn_Zuordng_MZ
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordng_MZ,
   Verwaltungskennziffern
      INTEGER NOT NULL REFERENCES Verwaltungskennziffern
)

CREATE TABLE verwtechn_Zuord_MZ__von_man_Zs (
   verwaltungstechn_Zuordng_MZ
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordng_MZ,
   manuelle_Zaehlst_abstrakt
      INTEGER NOT NULL REFERENCES manuelle_Zaehlst_abstrakt
)

CREATE TABLE Verwaltungskennziffern (
   Verwaltungskennziffern_ID
      INTEGER NOT NULL PRIMARY KEY,
   Regionskennziffer_1
      INTEGER NOT NULL,
   Regionskennziffer_2
      INTEGER NOT NULL,
   Kreiskennziffer
      INTEGER NOT NULL,
   Kennziffer_SM_AM
      INTEGER NOT NULL
)

CREATE TABLE Hochrechnungsergebnisse (
   Hochrechnungsergebnisse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Hochrechnungsergebnisse_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Fahrradzaehlung
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   Kradzaehlung
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean
)

CREATE TABLE Hochrechnerg__Fahrzeuggruppen (
   Hochrechnungsergebnisse
      INTEGER NOT NULL REFERENCES Hochrechnungsergebnisse,
   Fahrzeuggruppen
      VARCHAR(99) NOT NULL
)

CREATE TABLE Hochrechnerg__Datenbeschreib (
   Hochrechnungsergebnisse
      INTEGER NOT NULL REFERENCES Hochrechnungsergebnisse,
   Datenbeschreibung
      VARCHAR(99) NOT NULL
)

CREATE TABLE Hochrechnerg__von_man_Zaehlgr (
   Hochrechnungsergebnisse
      INTEGER NOT NULL REFERENCES Hochrechnungsergebnisse,
   manuelle_Zaehlst_abstrakt
      INTEGER NOT NULL REFERENCES manuelle_Zaehlst_abstrakt
)

CREATE TABLE Charakteristik (
   Charakteristik_ID
      INTEGER NOT NULL PRIMARY KEY,
   Charakteristik_1
      INTEGER NOT NULL REFERENCES Tab_Charakteristik,
   Charakteristik_2
      INTEGER NOT NULL REFERENCES Tab_Charakteristik,
   Charakteristik_3
      INTEGER NOT NULL REFERENCES Tab_Charakteristik,
   Lagekennung
      CHAR(1) NOT NULL REFERENCES Lagekennung,
   Netzknotenangaben
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   CHECK ( Charakteristik_3>=3 ),
   CHECK ( Charakteristik_2>=2 )
)

CREATE TABLE Charakt__hat_Ang_z_Strquerschn (
   Charakteristik
      INTEGER NOT NULL REFERENCES Charakteristik,
   Angaben_z_Strassenquerschnitt
      INTEGER NOT NULL REFERENCES Angaben_z_Strassenquerschnitt
)

CREATE TABLE Charakt__hat_Richtungskennung (
   Charakteristik
      INTEGER NOT NULL REFERENCES Charakteristik,
   Richtungskennung
      INTEGER NOT NULL REFERENCES Richtungskennung
)

CREATE TABLE Charakt__hat_Bemerkgskennziff (
   Charakteristik
      INTEGER NOT NULL REFERENCES Charakteristik,
   Bemerkungskennziffern
      INTEGER NOT NULL REFERENCES Bemerkungskennziffern
)

CREATE TABLE Tab_Charakteristik (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Charakteristik VALUES (1,'Kreuzung')
INSERT INTO Tab_Charakteristik VALUES (2,'Einmndung')
INSERT INTO Tab_Charakteristik VALUES (3,'Ein-/Ausfahrt Grundstck')
INSERT INTO Tab_Charakteristik VALUES (4,'Steigung/Geflle')
INSERT INTO Tab_Charakteristik VALUES (5,'Kuppe')
INSERT INTO Tab_Charakteristik VALUES (6,'Kurve')
INSERT INTO Tab_Charakteristik VALUES (7,'frei')
INSERT INTO Tab_Charakteristik VALUES (8,'Steigung')
INSERT INTO Tab_Charakteristik VALUES (9,'Geflle')

CREATE TABLE Lagekennung (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Lagekennung VALUES ('F','Freie Strecke')
INSERT INTO Lagekennung VALUES ('O','Ortsdurchfahrt')

CREATE TABLE Angaben_z_Strassenquerschnitt (
   Angaben_z_Strassenquerschnitt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Angaben_z_Strassenquerschnitt_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Anzahl_Fahrstreifen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_Fahrstreifen>=0 ),
   Anzahl_Standstreifen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_Standstreifen>=0 ),
   Anzahl_Mehrzweckstreifen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_Mehrzweckstreifen>=0 ),
   Anzahl_Radwege
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_Radwege>=0 ),
   Anzahl_Gleise
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_Gleise>=0 ),
   Anzahl_Breitenklasse
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_Breitenklasse>=0 )
)

CREATE TABLE Richtungskennung (
   Richtungskennung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Richtungskennung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Kennung
      INTEGER NOT NULL REFERENCES Tab_Richtungskennung
)

CREATE TABLE Tab_Richtungskennung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Richtungskennung VALUES (0,'GQ')
INSERT INTO Tab_Richtungskennung VALUES (1,'N')
INSERT INTO Tab_Richtungskennung VALUES (2,'O')
INSERT INTO Tab_Richtungskennung VALUES (3,'S')
INSERT INTO Tab_Richtungskennung VALUES (4,'W')

CREATE TABLE Bemerkungskennziffern (
   Bemerkungskennziffern_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bemerkungskennziffern_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Kennziffer_1
      INTEGER NOT NULL REFERENCES Kennziffer_1,
   Kennziffer_2
      INTEGER NOT NULL REFERENCES Kennziffer_2
)

CREATE TABLE Kennziffer_1 (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Kennziffer_1 VALUES (1,'keine aktuelle Zhlung')
INSERT INTO Kennziffer_1 VALUES (2,'manuelle und automatische Zhlung')
INSERT INTO Kennziffer_1 VALUES (3,'nur automatische Zhlung')
INSERT INTO Kennziffer_1 VALUES (4,'Knotenzhlstelle')
INSERT INTO Kennziffer_1 VALUES (5,'rechnerisch')

CREATE TABLE Kennziffer_2 (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Kennziffer_2 VALUES (1,'neue Zhlstelle')
INSERT INTO Kennziffer_2 VALUES (2,'Silhouettenzhlstelle')
INSERT INTO Kennziffer_2 VALUES (3,'Ergnzungszhlstelle')
INSERT INTO Kennziffer_2 VALUES (4,'neue und Ergnzungszhlstelle')

CREATE TABLE oertliche_Zuordnung_MZ (
   oertliche_Zuordnung_MZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_MZ_ID) REFERENCES Strassennetz.oertliche_Zuordnung,
   Sortiernummer
      INTEGER NOT NULL
)

CREATE TABLE oertl_Zuord_Mz__hat_ben_Anschl (
   oertliche_Zuordnung_MZ
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_MZ,
   benachbarte_Anschlussstellen
      INTEGER NOT NULL REFERENCES benachbarte_Anschlussstellen
)

CREATE TABLE oertl_Zuord_MZ__von_man_Zs (
   oertliche_Zuordnung_MZ
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_MZ,
   manuelle_Zaehlst_abstrakt
      INTEGER NOT NULL REFERENCES manuelle_Zaehlst_abstrakt
)

CREATE TABLE benachbarte_Anschlussstellen (
   benachbarte_Anschlussstellen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (benachbarte_Anschlussstellen_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   AS_von
      VARCHAR(50) NOT NULL,
   AS_bis
      VARCHAR(50) NOT NULL
)

CREATE TABLE Bezugszaehlstelle_Auslverkehr (
   Bezugszaehlstelle_Auslverkehr_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bezugszaehlstelle_Auslverkehr_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Land
      INTEGER NOT NULL,
   Bauamt
      INTEGER NOT NULL,
   TK25_Nummer
      INTEGER NOT NULL, -- TK25_Blattnummer
   CHECK ( ( TK25_Nummer >= 1 ) AND ( TK25_Nummer <= 9999 ) ),
   Zaehlstellennummer
      INTEGER NOT NULL
)

CREATE TABLE Bezugszaehlstelle_Gesamtverk (
   Bezugszaehlstelle_Gesamtverk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bezugszaehlstelle_Gesamtverk_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Land
      INTEGER NOT NULL,
   Bauamt
      INTEGER NOT NULL,
   TK25_Nummer
      INTEGER NOT NULL, -- TK25_Blattnummer
   CHECK ( ( TK25_Nummer >= 1 ) AND ( TK25_Nummer <= 9999 ) ),
   Zaehlstellennummer
      INTEGER NOT NULL
)

CREATE TABLE Angaben_zur_letzten_Zaehlung (
   Angaben_zur_letzten_Zaehlung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Land
      INTEGER NOT NULL,
   Bauamt
      INTEGER NOT NULL,
   Zaehlstellennummer
      INTEGER NOT NULL,
   TK25_Nummer
      INTEGER NOT NULL, -- TK25_Blattnummer
   CHECK ( ( TK25_Nummer >= 1 ) AND ( TK25_Nummer <= 9999 ) ),
   Strassenklasse
      CHAR(1) NOT NULL,
   Strassennummer
      INTEGER NOT NULL,
   Zusatz_Strassennummer
      CHAR(1) NOT NULL
)


