CREATE SCHEMA Unfall

-- Historie:
--
-- 31.05.2002 - 1.004 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 24.10.2001 - 1.003 (1.005)
-- Korrekturen in Schlsseltabellen
--
-- 12.09.2001 - 1.002 (1.004)
-- Schema komplett bezglich EUDAS-95 berarbeitet
--
-- 17.12.2000 - 1.001 (1.002)
-- Verlegung der oertlichen_Zuordnung in das Straennetz
--
-- Verlegung der verwaltungstechn_Zuordnung in die Administration
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Unfall (
   Unfall_ID
      INTEGER NOT NULL PRIMARY KEY,
   Paginiernummer
      VARCHAR(5) NOT NULL,
   laufende_jaehrliche_Nummer
      INTEGER,
   lfd_Nr_d_Unfallhaeufungsstelle
      INTEGER,
   Unfallort
      INTEGER REFERENCES Angaben_zum_Unfallort,
   Unfallzeit
      INTEGER REFERENCES Angaben_zur_Unfallzeit,
   Unfallgeschehen
      INTEGER REFERENCES Angaben_zum_Unfallgeschehen,
   Unfallumstaende
      INTEGER REFERENCES Angaben_zu_Unfallumstaenden,
   Unfallbeteiligte
      INTEGER REFERENCES Angaben_zu_Unfallbeteiligten,
   DV_Merkmale_StaLa
      INTEGER REFERENCES DV_Merkmale_StaLa
)

CREATE TABLE Angaben_zum_Unfallort (
   Angaben_zum_Unfallort_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Angaben_zum_Unfallort_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   Fahrtrichtung
      INTEGER REFERENCES Fahrtrichtung,
   Teilabschnittsnummer
      INTEGER,
   in_Verwaltungsbezirk
      INTEGER REFERENCES Administration.Verwaltungsbezirk_abstrakt,
   bei_Bauamt
      INTEGER REFERENCES Administration.Strassenbaudienstst_abstr,
   bei_Polizeidienststelle
      INTEGER REFERENCES Administration.Polizeidienststelle,
   Ortslage_gemaess_SIB
      INTEGER REFERENCES Administration.OD_FS,
   auf_kommunaler_Strasse
      INTEGER REFERENCES kommunale_Strasse,
   an_Strassenpunkt
      INTEGER REFERENCES Unfallort_Strassenpunkt,
   einmuendende_kommunale_Strasse
      INTEGER REFERENCES kommunale_Strasse
)

CREATE TABLE Ang_z_Unfort__auf_klassif_Str (
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Angaben_zum_Unfallort,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strassennetz.Strasse_abstrakt
)

CREATE TABLE Ang_z_Unfort__bei_Betriebskm (
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Angaben_zum_Unfallort,
   Kilometrierung
      INTEGER NOT NULL REFERENCES Strassennetz.Kilometrierung
)

CREATE TABLE Ang_z_Unfort__einm_kl_Str_Anfg (
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Angaben_zum_Unfallort,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strassennetz.Strasse_abstrakt
)

CREATE TABLE Ang_z_Unfort__einm_kl_Str_Ende (
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Angaben_zum_Unfallort,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strassennetz.Strasse_abstrakt
)

CREATE TABLE Fahrtrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Fahrtrichtung VALUES (1,'Fahrtrichtung in aufsteigender ' ||
'Stationierungsrichtung')
INSERT INTO Fahrtrichtung VALUES (2,'Fahrtrichtung in absteigender ' ||
'Stationierungsrichtung')

CREATE TABLE kommunale_Strasse (
   kommunale_Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Strassenschluessel
      VARCHAR(9) NOT NULL,
   Hausnummer
      INTEGER NOT NULL
)

CREATE TABLE Unfallort_Strassenpunkt (
   Unfallort_Strassenpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Unfallort_Strassenpunkt_ID) REFERENCES Strassennetz.Punktobjekt_stat
)

CREATE TABLE Angaben_zur_Unfallzeit (
   Angaben_zur_Unfallzeit_ID
      INTEGER NOT NULL PRIMARY KEY,
   Unfalldatum
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Unfalldatum LIKE '__.__.____' ),
   Wochentag
      INTEGER REFERENCES Allgemeine_Objekte.Wochentag,
   Unfallzeit
      VARCHAR(12) NOT NULL, -- Uhrzeit
   CHECK ( ( Unfallzeit LIKE '__:__' ) OR ( Unfallzeit LIKE '__:__:__' ) OR ( Unfallzeit LIKE '__:__:__:___' ) ),
   Feiertag
      INTEGER REFERENCES Logical_Types.Boolean
)

CREATE TABLE Angaben_zum_Unfallgeschehen (
   Angaben_zum_Unfallgeschehen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Unfallart
      INTEGER NOT NULL REFERENCES Unfallart,
   Unfallkategorie
      INTEGER NOT NULL REFERENCES Unfallkategorie,
   Unfalltyp
      INTEGER NOT NULL REFERENCES Unfalltyp,
   Gesamtsachschaden
      REAL, -- Waehrung
   CHECK ( Gesamtsachschaden>=0 ),
   Kfz_fahrbereit
      INTEGER REFERENCES Logical_Types.Boolean
)

CREATE TABLE Ang_z_Unfgesch__vorl_Unfallurs (
   Angaben_zum_Unfallgeschehen
      INTEGER NOT NULL REFERENCES Angaben_zum_Unfallgeschehen,
   Unfallursache
      INTEGER NOT NULL REFERENCES Unfallursache
)

CREATE TABLE Unfallart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Unfallart VALUES (1,'Zusammensto mit Fahrzeug, das anfhrt, ' ||
'anhlt, im ruhenden Verkehr steht')
INSERT INTO Unfallart VALUES (2,'Zusammensto mit Fahrzeug, das ' ||
'vorausfhrt oder wartet')
INSERT INTO Unfallart VALUES (3,'Zusammensto mit Fahrzeug, das seitlich ' ||
'in gleicher Richtung fhrt')
INSERT INTO Unfallart VALUES (4,'Zusammensto mit Fahrzeug, das entgegenkommt')
INSERT INTO Unfallart VALUES (5,'Zusammensto mit Fahrzeug, das einbiegt ' ||
'oder kreuzt')
INSERT INTO Unfallart VALUES (6,'Zusammensto zwischen Fahrzeug und ' ||
'Fugnger')
INSERT INTO Unfallart VALUES (7,'Aufprall auf Hindernis auf der Fahrbahn')
INSERT INTO Unfallart VALUES (8,'Abkommen von Fahrbahn nach rechts')
INSERT INTO Unfallart VALUES (9,'Abkommen von Fahrbahn nach links')
INSERT INTO Unfallart VALUES (0,'Unfall anderer Art')

CREATE TABLE Unfallursache (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Unfallursache VALUES (70,'Glatte oder schlpfrige Fahrbahn ' ||
'durch l')
INSERT INTO Unfallursache VALUES (71,'Glatte oder schlpfrige Fahrbahn ' ||
'durch andere Verunreinigungen')
INSERT INTO Unfallursache VALUES (72,'Glatte oder schlpfrige Fahrbahn ' ||
'durch Schnee/Eis')
INSERT INTO Unfallursache VALUES (73,'Glatte oder schlpfrige Fahrbahn ' ||
'durch Regen')
INSERT INTO Unfallursache VALUES (74,'Glatte oder schlpfrige Fahrbahn ' ||
'durch andere Einflsse (Laub/Lehm)')
INSERT INTO Unfallursache VALUES (75,'Spurrillen im Zusammenhang mit ' ||
'Regen/Schnee/Eis')
INSERT INTO Unfallursache VALUES (76,'Anderer Zustand der Strae')
INSERT INTO Unfallursache VALUES (77,'Kein ordnungsgemer Zustand der ' ||
'Verkehrszeichen/-Einrichtungen')
INSERT INTO Unfallursache VALUES (78,'Mangelhafte Beleuchtung der Strae')
INSERT INTO Unfallursache VALUES (79,'Mangelhafte Sicherung von ' ||
'Bahnbergngen')
INSERT INTO Unfallursache VALUES (80,'Sichtbehinderung durch Nebel')
INSERT INTO Unfallursache VALUES (81,'Sichtbehinderung durch starken ' ||
'Regen, Hagel, Schneegestber')
INSERT INTO Unfallursache VALUES (82,'Sichtbehinderung durch blendende Sonne')
INSERT INTO Unfallursache VALUES (83,'Seitenwind')
INSERT INTO Unfallursache VALUES (84,'Sichtbehinderung durch Unwetter oder ' ||
'sonstigen Witterungseinfluss')
INSERT INTO Unfallursache VALUES (85,'Nicht oder unzureichend gesicherte ' ||
'gesicherte Arbeitsstelle auf der Fahrbahn')
INSERT INTO Unfallursache VALUES (86,'Wild auf der Fahrbahn')
INSERT INTO Unfallursache VALUES (87,'Anderes Tier auf der Fahrbahn')
INSERT INTO Unfallursache VALUES (88,'Sonstiges Hindernis auf der Fahrbahn')
INSERT INTO Unfallursache VALUES (89,'Sonstige Ursachen')

CREATE TABLE Unfallkategorie (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Unfallkategorie VALUES (1,'Unfall mit Getteten')
INSERT INTO Unfallkategorie VALUES (2,'Unfall mit Schwerverletzten')
INSERT INTO Unfallkategorie VALUES (3,'Unfall mit Leichtverletzten')
INSERT INTO Unfallkategorie VALUES (4,'Unfall mit schwerem Sachschaden')
INSERT INTO Unfallkategorie VALUES (5,'Unfall mit leichtem Sachschaden')
INSERT INTO Unfallkategorie VALUES (6,'sonstiger Sachschadensunfall unter ' ||
'Alkoholeinwirkung')
INSERT INTO Unfallkategorie VALUES (8,'schwerwiegender Unfall mit ' ||
'Sachschaden (mindestens ein Kfz nicht fahrbereit (einschlielich ' ||
'Alkoholeinwirkung')
INSERT INTO Unfallkategorie VALUES (9,'sonstiger Sachschadensunfall ohne ' ||
'Alkoholeinwirkung')

CREATE TABLE Unfalltyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Unfalltyp VALUES (1,'Fahrunfall')
INSERT INTO Unfalltyp VALUES (2,'Abbiegeunfall')
INSERT INTO Unfalltyp VALUES (3,'Einbiege-/Kreuzungs-Unfall')
INSERT INTO Unfalltyp VALUES (4,'Unfall durch Strae berschreitenden ' ||
'Fugnger')
INSERT INTO Unfalltyp VALUES (5,'Unfall durch haltendes oder parkendes ' ||
'Fahrzeug')
INSERT INTO Unfalltyp VALUES (6,'Lngsunfall')
INSERT INTO Unfalltyp VALUES (7,'Sonstiger Unfall')

CREATE TABLE Angaben_zu_Unfallumstaenden (
   Angaben_zu_Unfallumstaenden_ID
      INTEGER NOT NULL PRIMARY KEY,
   Geschwindigkeitsbegrenzung
      INTEGER, -- Stundenkilometer
   CHECK ( Geschwindigkeitsbegrenzung>=0 ),
   Strassenbefestigung
      INTEGER REFERENCES Strassenbefestigung,
   Alkoholeinwirkung
      INTEGER REFERENCES Logical_Types.Boolean,
   Verkehrsflucht
      INTEGER REFERENCES Logical_Types.Boolean,
   Aquaplaning
      INTEGER REFERENCES Logical_Types.Boolean,
   Aufprall_auf_Hindernis
      INTEGER REFERENCES Hindernisart,
   hat_DTV_im_Gesamtquerschnitt
      INTEGER REFERENCES Verkehrsstaerke.alle_Tage
)

CREATE TABLE Ang_zu_Unfumst__Char_d_Unfst (
   Angaben_zu_Unfallumstaenden
      INTEGER NOT NULL REFERENCES Angaben_zu_Unfallumstaenden,
   Charakteristik_d_Unfallstelle
      INTEGER NOT NULL REFERENCES Charakteristik_d_Unfallstelle
)

CREATE TABLE Ang_zu_Unfumst__Bes_d_Unfallst (
   Angaben_zu_Unfallumstaenden
      INTEGER NOT NULL REFERENCES Angaben_zu_Unfallumstaenden,
   Besonderheiten_d_Unfallstelle
      INTEGER NOT NULL REFERENCES Besonderheiten_d_Unfallstelle
)

CREATE TABLE Ang_zu_Unfumst__Verkehrsregelg (
   Angaben_zu_Unfallumstaenden
      INTEGER NOT NULL REFERENCES Angaben_zu_Unfallumstaenden,
   Verkehrsregelung
      INTEGER NOT NULL REFERENCES Verkehrsregelung
)

CREATE TABLE Ang_zu_Unfumst__Lichtverhaeltn (
   Angaben_zu_Unfallumstaenden
      INTEGER NOT NULL REFERENCES Angaben_zu_Unfallumstaenden,
   Lichtverhaeltnisse
      INTEGER NOT NULL REFERENCES Lichtverhaeltnisse
)

CREATE TABLE Ang_zu_Unfumst__Strassenzustd (
   Angaben_zu_Unfallumstaenden
      INTEGER NOT NULL REFERENCES Angaben_zu_Unfallumstaenden,
   Strassenzustand
      INTEGER NOT NULL REFERENCES Strassenzustand
)

CREATE TABLE Ang_zu_Unfumst__Witterung (
   Angaben_zu_Unfallumstaenden
      INTEGER NOT NULL REFERENCES Angaben_zu_Unfallumstaenden,
   Witterung
      INTEGER NOT NULL REFERENCES Witterung
)

CREATE TABLE Charakteristik_d_Unfallstelle (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Charakteristik_d_Unfallstelle VALUES (1,'Kreuzung')
INSERT INTO Charakteristik_d_Unfallstelle VALUES (2,'Einmndung/Anschlu')
INSERT INTO Charakteristik_d_Unfallstelle VALUES (3,'Grundstcksein- oder ' ||
'-ausfahrt')
INSERT INTO Charakteristik_d_Unfallstelle VALUES (4,'Steigung/Geflle')
INSERT INTO Charakteristik_d_Unfallstelle VALUES (5,'Kuppe')
INSERT INTO Charakteristik_d_Unfallstelle VALUES (6,'Kurve')
INSERT INTO Charakteristik_d_Unfallstelle VALUES (8,'Steigung')
INSERT INTO Charakteristik_d_Unfallstelle VALUES (9,'Geflle')

CREATE TABLE Besonderheiten_d_Unfallstelle (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Besonderheiten_d_Unfallstelle VALUES (1,'Unbersichtlich')
INSERT INTO Besonderheiten_d_Unfallstelle VALUES (2,'Schienengleicher ' ||
'Wegbergang')
INSERT INTO Besonderheiten_d_Unfallstelle VALUES (3,'Fugngerberweg ' ||
'(Zebrastreifen)')
INSERT INTO Besonderheiten_d_Unfallstelle VALUES (4,'Fugngerfurt')
INSERT INTO Besonderheiten_d_Unfallstelle VALUES (5,'Haltestelle')
INSERT INTO Besonderheiten_d_Unfallstelle VALUES (6,'Arbeitsstelle')
INSERT INTO Besonderheiten_d_Unfallstelle VALUES (7,'Verkehrsberuhigter ' ||
'Bereich (Z325)')
INSERT INTO Besonderheiten_d_Unfallstelle VALUES (8,'Querungshilfe')
INSERT INTO Besonderheiten_d_Unfallstelle VALUES (9,'Kreisverkehr')

CREATE TABLE Verkehrsregelung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Verkehrsregelung VALUES (7,'Verkehrsregelungsposten')
INSERT INTO Verkehrsregelung VALUES (8,'Lichtzeichenanlage in Betrieb')
INSERT INTO Verkehrsregelung VALUES (9,'Lichtzeichenanlage auer Betrieb')

CREATE TABLE Lichtverhaeltnisse (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Lichtverhaeltnisse VALUES (0,'Tageslicht')
INSERT INTO Lichtverhaeltnisse VALUES (1,'Dmmerung')
INSERT INTO Lichtverhaeltnisse VALUES (2,'Dunkelheit')
INSERT INTO Lichtverhaeltnisse VALUES (3,'Straenbeleuchtung in Betrieb')
INSERT INTO Lichtverhaeltnisse VALUES (4,'Straenbeleuchtung auer Betrieb')

CREATE TABLE Strassenbefestigung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Strassenbefestigung VALUES (5,'Betondecke')
INSERT INTO Strassenbefestigung VALUES (6,'Schwarzdecke')
INSERT INTO Strassenbefestigung VALUES (7,'Pflaster')
INSERT INTO Strassenbefestigung VALUES (8,'Sonstige befestigte Strae')
INSERT INTO Strassenbefestigung VALUES (9,'Unbefestigte Strae')

CREATE TABLE Strassenzustand (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Strassenzustand VALUES (0,'Trocken')
INSERT INTO Strassenzustand VALUES (1,'Nass/Feucht')
INSERT INTO Strassenzustand VALUES (2,'Glatteis')
INSERT INTO Strassenzustand VALUES (3,'Schneegltte')
INSERT INTO Strassenzustand VALUES (4,'Gestreut')
INSERT INTO Strassenzustand VALUES (5,'Schlpfrigkeit (l, Dung, Laub usw.)')
INSERT INTO Strassenzustand VALUES (6,'Schadhafte Fahrbahn')
INSERT INTO Strassenzustand VALUES (7,'Winterglatt')

CREATE TABLE Witterung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Witterung VALUES (7,'Regen')
INSERT INTO Witterung VALUES (8,'Schneefall/Hagel')
INSERT INTO Witterung VALUES (9,'Nebel/Dunst')
INSERT INTO Witterung VALUES (0,'Sturm/Ben')

CREATE TABLE Verkehrsstufe (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Verkehrsstufe VALUES (1,'Schwacher Verkehr')
INSERT INTO Verkehrsstufe VALUES (2,'Lebhafter Verkehr')
INSERT INTO Verkehrsstufe VALUES (3,'Dichter Verkehr')
INSERT INTO Verkehrsstufe VALUES (4,'Zhflssiger Verkehr')
INSERT INTO Verkehrsstufe VALUES (5,'Stau')

CREATE TABLE Hindernisart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Hindernisart VALUES (0,'Baum')
INSERT INTO Hindernisart VALUES (1,'Mast')
INSERT INTO Hindernisart VALUES (2,'Widerlager')
INSERT INTO Hindernisart VALUES (3,'Schutzplanke')
INSERT INTO Hindernisart VALUES (4,'sonstiges Hindernis')
INSERT INTO Hindernisart VALUES (5,'kein Aufprall')

CREATE TABLE Angaben_zu_Unfallbeteiligten (
   Angaben_zu_Unfallbeteiligten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Anzahl_der_Beteiligten
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_der_Beteiligten >= 0 ) AND ( Anzahl_der_Beteiligten <= 99 ) ),
   Anzahl_der_Getoeteten
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_der_Getoeteten >= 0 ) AND ( Anzahl_der_Getoeteten <= 99 ) ),
   Anzahl_der_Schwerverletzten
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_der_Schwerverletzten >= 0 ) AND ( Anzahl_der_Schwerverletzten <= 99 ) ),
   Anzahl_der_Leichtverletzten
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_der_Leichtverletzten >= 0 ) AND ( Anzahl_der_Leichtverletzten <= 99 ) )
)

CREATE TABLE Unfallbeteiligter (
   Unfallbeteiligter_ID
      INTEGER NOT NULL PRIMARY KEY,
   Alter
      INTEGER,
   Geschlecht
      INTEGER REFERENCES Geschlecht,
   Art_der_Verkehrsbeteiligung
      INTEGER REFERENCES Art_der_Verkehrsbeteiligung,
   Ortskenntnisse_vorhanden
      INTEGER REFERENCES Logical_Types.Boolean,
   Wohnsitz_Auslaender
      INTEGER REFERENCES Wohnsitz_Ausl,
   Nationalitaetenzeichen
      VARCHAR(3),
   Art_der_Verletzung
      INTEGER REFERENCES Art_der_Verletzung,
   Anzahl_Fahrzeugbenutzer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_Fahrzeugbenutzer >= 0 ) AND ( Anzahl_Fahrzeugbenutzer <= 99 ) ),
   Anzahl_getoetete_Mitfahrer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_getoetete_Mitfahrer >= 0 ) AND ( Anzahl_getoetete_Mitfahrer <= 99 ) ),
   Anzahl_schwerverl_Mitfahrer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_schwerverl_Mitfahrer >= 0 ) AND ( Anzahl_schwerverl_Mitfahrer <= 99 ) ),
   Anzahl_leichtverl_Mitfahrer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_leichtverl_Mitfahrer >= 0 ) AND ( Anzahl_leichtverl_Mitfahrer <= 99 ) ),
   Fahrerlaubnis_vorhanden
      INTEGER REFERENCES Logical_Types.Boolean,
   Datum_Fahrerlaubnis
      CHAR(10), -- Datum
   CHECK ( Datum_Fahrerlaubnis LIKE '__.__.____' ),
   Geburtsdatum
      CHAR(10), -- Datum
   CHECK ( Geburtsdatum LIKE '__.__.____' ),
   Blutalkoholkonzentration
      REAL, -- Promille
   CHECK ( Blutalkoholkonzentration>=0 ),
   Verkehrsflucht
      INTEGER REFERENCES Logical_Types.Boolean,
   Ordnungsnummer
      INTEGER,
   hat_Angaben_zum_Kraftfahrzeug
      INTEGER REFERENCES Unfallfahrzeug,
   von_Ang_zu_Unfallbeteiligten
      INTEGER NOT NULL REFERENCES Angaben_zu_Unfallbeteiligten
)

CREATE TABLE Unfallbet__hat_spez_Unfallurs (
   Unfallbeteiligter
      INTEGER NOT NULL REFERENCES Unfallbeteiligter,
   Unfallursache
      INTEGER NOT NULL REFERENCES Unfallursache
)

CREATE TABLE Geschlecht (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Geschlecht VALUES (1,'m')
INSERT INTO Geschlecht VALUES (2,'w')

CREATE TABLE Art_der_Verkehrsbeteiligung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_der_Verkehrsbeteiligung VALUES (1,'Moped/Mokick')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (2,'Mofa 25')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (11,'Kraftrad/Motorrad')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (12,'Leichtkraftrad/' ||
'Kleinkraftrad')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (15,'Kraftroller')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (21,'Personenkraftwagen')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (31,'Kraftomnibus')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (32,'Reisebus')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (33,'Linienbus')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (34,'Schulbus')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (35,'Oberleitungsomnibus')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (41,'Liefer- und ') ||
'Lastkraftwagen ohne Anhnger')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (43,'Liefer- und ') ||
'Lastkraftwagen mit Tankauflagen, ohne Anhnger')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (45,'Liefer- und ') ||
'Lastkraftwagen mit Anhnger')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (48,'Liefer- und ') ||
'Lastkraftwagen mit Tankauflagen, mit Anhnger')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (51,'Sattelschlepper')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (52,'Sattelschlepper mit ') ||
'Auflieger als Tankwagen')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (53,'Landwirtschaftl. ') ||
'Zugmaschinen')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (54,'Andere Zugmaschinen')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (55,'Andere Zugmaschinen ') ||
'mit Tankwagen zur Befrderung von gefhrlichen Gtern')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (57,'Tankkraftwagen zur ') ||
'Befrderung von gefhrlichen Gtern')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (58,'Lastkraftwagen mit ') ||
'Spezialaufbau')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (59,'brige Kraftfahrzeuge')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (61,'Straenbahnen')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (62,'Eisenbahnen')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (71,'Fahrrder')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (81,'Fugnger')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (82,'Handwagen,-karren')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (83,'Tierfhrer,-treiber')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (91,'Bespannte Fuhrwerke')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (92,'Sonstige und ') ||
'unbekannte Fahrzeuge')
INSERT INTO Art_der_Verkehrsbeteiligung VALUES (93,'Andere Personen')

CREATE TABLE Wohnsitz_Ausl (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Wohnsitz_Ausl VALUES (1,'Wohnsitz in Deutschland')
INSERT INTO Wohnsitz_Ausl VALUES (2,'Wohnsitz im Ausland')

CREATE TABLE Art_der_Verletzung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_der_Verletzung VALUES (1,'gettet')
INSERT INTO Art_der_Verletzung VALUES (2,'schwerverletzt')
INSERT INTO Art_der_Verletzung VALUES (3,'leichtverletzt')

CREATE TABLE Mitfahrer (
   Mitfahrer_ID
      INTEGER NOT NULL PRIMARY KEY,
   laufende_Nummer
      INTEGER,
   Art_der_Verletzung
      INTEGER REFERENCES Art_der_Verletzung,
   Geschlecht
      INTEGER REFERENCES Geschlecht,
   Alter
      INTEGER,
   von_Unfallteiligtem
      INTEGER NOT NULL REFERENCES Unfallbeteiligter
)

CREATE TABLE Unfallfahrzeug (
   Unfallfahrzeug_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kennzeichen
      VARCHAR(10),
   Nationalitaetenkennzeichen
      VARCHAR(3),
   zulaessiges_Gesamtgewicht
      REAL, -- Kilogramm
   CHECK ( zulaessiges_Gesamtgewicht >= 0 ),
   Zusatzsignatur_LKR_und_PKW
      INTEGER REFERENCES Art_der_Verkehrsbeteiligung,
   Freisetzung_von_Gefahrgut
      INTEGER REFERENCES Logical_Types.Boolean,
   Jahr_Erstzulassung
      INTEGER, -- Jahr
   Gefahrklasse
      CHAR(3) REFERENCES Gefahrklasse,
   Gefahrgutkennzeichen
      CHAR(4) REFERENCES Gefahrgutkennzeichen,
   Hoehe_des_Sachschadens
      REAL, -- Waehrung
   CHECK ( Hoehe_des_Sachschadens >= 0 ),
   Aufprall_auf_Hindernis
      INTEGER REFERENCES Hindernisart,
   Kfz_fahrbereit
      INTEGER REFERENCES Logical_Types.Boolean,
   Leergewicht
      REAL, -- Kilogramm
   CHECK ( Leergewicht >= 0 ),
   Anhaenger_vorhanden
      INTEGER REFERENCES Logical_Types.Boolean,
   Typschluessel
      VARCHAR(11),
   Fahrzeugart
      VARCHAR(2),
   Aufbauart
      VARCHAR(2),
   Motorleistung
      INTEGER, -- Kilowatt
   CHECK ( Motorleistung >= 0 ),
   Hubraum
      REAL, -- Kubikzentimeter
   CHECK ( Hubraum >= 0 ),
   Hoechstgeschwindigkeit
      INTEGER, -- Stundenkilometer
   CHECK ( Hoechstgeschwindigkeit >= 0 ),
   Anzahl_der_Achsen
      INTEGER, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_der_Achsen >= 0 ) AND ( Anzahl_der_Achsen <= 99 ) ),
   Anzahl_angetriebene_Achsen
      INTEGER, -- Anzahl_einstellig
   CHECK ( ( Anzahl_angetriebene_Achsen >= 0 ) AND ( Anzahl_angetriebene_Achsen <= 9 ) ),
   UN_Nummer
      VARCHAR(4),
   sonstiges_befoerd_Gefahrgut
      CHAR(1),
   Nummer_der_Ausnahmeverordnung
      INTEGER,
   Zusatzgutachten_vorhanden
      INTEGER REFERENCES Logical_Types.Boolean,
   Kfz_in_Verwaltungsbezirk
      INTEGER REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

CREATE TABLE Gefahrklasse (
   Kennung
      CHAR(3) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

CREATE TABLE Gefahrgutkennzeichen (
   Kennung
      CHAR(4) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

CREATE TABLE DV_Merkmale_StaLa (
   DV_Merkmale_StaLa_ID
      INTEGER NOT NULL PRIMARY KEY,
   landesinterne_Angaben
      VARCHAR(255),
   Sondererhebungen
      VARCHAR(3),
   Berichtsjahr
      INTEGER, -- Jahr
   Berichtsmonat
      INTEGER, -- Monat
   CHECK ( ( Berichtsmonat >= 1 ) AND ( Berichtsmonat <= 12 ) ),
   Durchlaufnummer
      INTEGER, -- Anzahl_zweistellig
   CHECK ( ( Durchlaufnummer >= 0 ) AND ( Durchlaufnummer <= 99 ) ),
   Fehlerbyte
      CHAR(1),
   Kennz_fuer_Materialergaenzung
      CHAR(1),
   in_Bundesland
      INTEGER REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

